@@ -238,8 +238,7 @@ void Notification::stateChanged(NetworkManager::Device::State newstate,
         text = i18nc("@info:status Notification when the device failed due to ModemManagerUnavailable", "ModemManager not running");
         break;
     case NetworkManager::Device::SsidNotFound:
-        text = i18nc("@info:status Notification when the device failed due to SsidNotFound", "The WiFi network could not be found");
-        break;
+        return;
     case NetworkManager::Device::SecondaryConnectionFailed:
         text =
             i18nc("@info:status Notification when the device failed due to SecondaryConnectionFailed", "A secondary connection of the base connection failed");
@@ -382,7 +381,9 @@ void Notification::onActiveConnectionStateChanged(NetworkManager::ActiveConnecti
             break;
         }
     } else {
-        qCWarning(PLASMA_NM_KDED_LOG) << "Unhandled active connection state change: " << state;
+        if (state != NetworkManager::ActiveConnection::Activating && state != NetworkManager::ActiveConnection::Deactivating) {
+            qCWarning(PLASMA_NM_KDED_LOG) << "Unhandled active connection state change: " << state;
+        }
         return;
     }
 
