@@ -7,32 +7,29 @@
 #ifndef PLASMA_NM_HANDLER_H
 #define PLASMA_NM_HANDLER_H
 
+#include "plasmanm_internal_export.h"
+
 #include <QDBusInterface>
+#include <QDBusPendingCallWatcher>
 #include <QPointer>
 #include <QTimer>
 
+#include <qqmlregistration.h>
+
 #include <ModemManagerQt/GenericTypes>
 #include <NetworkManagerQt/Connection>
 #include <NetworkManagerQt/ConnectionSettings>
 #include <NetworkManagerQt/Settings>
 #include <NetworkManagerQt/Utils>
 
-class Q_DECL_EXPORT Handler : public QObject
+#include <QCoroCore>
+
+class PLASMANM_INTERNAL_EXPORT Handler : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
 
 public:
-    enum HandlerAction {
-        ActivateConnection,
-        AddAndActivateConnection,
-        AddConnection,
-        DeactivateConnection,
-        RemoveConnection,
-        RequestScan,
-        UpdateConnection,
-        CreateHotspot,
-    };
-
     explicit Handler(QObject *parent = nullptr);
     ~Handler() override;
 
@@ -52,6 +49,8 @@ public:
         return m_ongoingScansCount != 0;
     }
 
+    void addConnection(NMConnection *connection);
+
 public Q_SLOTS:
     /**
      * Activates given connection
@@ -85,16 +84,13 @@ public Q_SLOTS:
      */
     void requestWifiCode(const QString &connectionPath,
                          const QString &ssid,
-                         /*NetworkManager::WirelessSecurityType*/ int securityType,
-                         const QString &connectionName);
+                         /*NetworkManager::WirelessSecurityType*/ int securityType);
 
     /**
      * Adds a new connection
      * @map - NMVariantMapMap with connection settings
      */
-    void addConnection(const NMVariantMapMap &map);
-
-    void addConnection(NMConnection *connection);
+    QCoro::Task<void> addConnection(const NMVariantMapMap &map);
 
     /**
      * Deactivates given connection
@@ -122,7 +118,7 @@ public Q_SLOTS:
      * @connection - connection which should be updated
      * @map - NMVariantMapMap with new connection settings
      */
-    void updateConnection(const NetworkManager::Connection::Ptr &connection, const NMVariantMapMap &map);
+    QCoro::Task<void> updateConnection(NetworkManager::Connection::Ptr connection, const NMVariantMapMap &map);
     void requestScan(const QString &interface = QString());
 
     void createHotspot();
@@ -130,8 +126,6 @@ public Q_SLOTS:
 
 private Q_SLOTS:
     void secretAgentError(const QString &connectionPath, const QString &message);
-    void replyFinished(QDBusPendingCallWatcher *watcher);
-    void hotspotCreated(QDBusPendingCallWatcher *watcher);
     void primaryConnectionTypeChanged(NetworkManager::ConnectionSettings::ConnectionType type);
     void unlockRequiredChanged(MMModemLock modemLock);
     void slotRequestWifiCode(QDBusPendingCallWatcher *watcher);
@@ -142,10 +136,16 @@ Q_SIGNALS:
     void hotspotDisabled();
     void hotspotSupportedChanged(bool hotspotSupported);
     void scanningChanged();
-    void wifiCodeReceived(const QString &data, const QString &connectionName);
+    void wifiCodeReceived(const QString &data, const QString &ssid);
 
 private:
-    void addAndActivateConnectionDBus(const NMVariantMapMap &map, const QString &device, const QString &specificObject);
+    QCoro::Task<void> addAndActivateConnectionDBus(const NMVariantMapMap &map, const QString &device, const QString &specificObject);
+    QCoro::Task<void> activateConnectionInternal(const QString &connection, const QString &device, const QString &specificParameter);
+    QCoro::Task<void> addAndActivateConnectionInternal(const QString &device, const QString &specificParameter, const QString &password = QString());
+    QCoro::Task<void> deactivateConnectionInternal(const QString &connection, const QString &device);
+    QCoro::Task<void> removeConnectionInternal(const QString &connection);
+    QCoro::Task<void> requestScanInternal(const QString &interface = QString());
+    QCoro::Task<void> createHotspotInternal();
 
     bool m_hotspotSupported;
     bool m_tmpWirelessEnabled;
@@ -158,7 +158,7 @@ private:
     QMap<QString, QTimer *> m_wirelessScanRetryTimer;
     short m_ongoingScansCount = 0;
 
-    void enableBluetooth(bool enable);
+    QCoro::Task<void> enableBluetooth(bool enable);
     void scanRequestFailed(const QString &interface);
     bool checkRequestScanRateLimit(const NetworkManager::WirelessDevice::Ptr &wifiDevice);
     bool checkHotspotSupported();
